==> dscript-1.0.0.tgz: package/lib/index.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var _htmlTags = require('html-tags');

var _htmlTags2 = _interopRequireDefault(_htmlTags);

var _objectAssign = require('object-assign');

var _objectAssign2 = _interopRequireDefault(_objectAssign);

var _parseCssClassIdSelector = require('parse-css-class-id-selector');

var _parseCssClassIdSelector2 = _interopRequireDefault(_parseCssClassIdSelector);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * Retrieve class names and id from a selector
 * @param {String} selector - CSS class and/or id selector to parse
 * @return {Object} - object with class and id properties, if found in selector
 *   {String} class
 *   {String} id
 */
var getClassesAndId = function getClassesAndId(selector) {
  var _parseCssClassIdSelec = (0, _parseCssClassIdSelector2.default)(selector);

  var classNames = _parseCssClassIdSelec.classNames;
  var id = _parseCssClassIdSelec.id;


  var classesAndId = {};

  if (classNames.length) {
    classesAndId.class = classNames.join(' ');
  }

  if (id) {
    classesAndId.id = id;
  }

  return classesAndId;
};

/**
 * Return a creator function with properties having HTML tag names with values
 * being creator functions for the respective HTML element.
 *
 * The stand-alone returned creator function is meant to be used with custom
 * components
 *
 * @param {Function} createElement - function producing virtual nodes - typically the function used for JSX
 * @return {Function} - explained above
 */
module.exports = function (createElement) {
  if (typeof createElement !== 'function') {
    throw new TypeError('Expected createElement to be a function');
  }

  var creator = function creator(tagOrComponent) {
    return function (classesAndId, attrs) {
      for (var _len = arguments.length, children = Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
        children[_key - 2] = arguments[_key];
      }

      var attrsToPass = attrs || {},
          childrenToPass = children || [];

      if (Array.isArray(attrsToPass)) {
        // case: div('.hello', ['hi'])
        childrenToPass = attrsToPass;
        attrsToPass = {};
      }

      if (Array.isArray(classesAndId)) {
        // case: div(['hi'])
        childrenToPass = classesAndId;
      } else if ((typeof classesAndId === 'undefined' ? 'undefined' : _typeof(classesAndId)) === 'object') {
        // case: div({tabindex: 4})
        attrsToPass = classesAndId;
      }

      if (typeof classesAndId === 'string') {
        // case: div('.hello')
        (0, _objectAssign2.default)(attrsToPass, getClassesAndId(classesAndId));
      }

      return createElement.apply(undefined, [tagOrComponent, attrsToPass].concat(_toConsumableArray(childrenToPass)));
    };
  };

  // attach each HTML creator function to a creator function for custom components
  return _htmlTags2.default.reduce(function (acc, tag) {
    acc[tag] = creator(tag);
    return acc;
  }, creator);
};

==> dscript-1.1.0.tgz: package/lib/index.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var _htmlTags = require('html-tags');

var _htmlTags2 = _interopRequireDefault(_htmlTags);

var _objectAssign = require('object-assign');

var _objectAssign2 = _interopRequireDefault(_objectAssign);

var _parseCssClassIdSelector = require('parse-css-class-id-selector');

var _parseCssClassIdSelector2 = _interopRequireDefault(_parseCssClassIdSelector);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * Retrieve class names and id from a selector
 * @param {String} selector - CSS class and/or id selector to parse
 * @return {Object} - object with class and id properties, if found in selector
 *   {String} class
 *   {String} id
 */
var getClassesAndId = function getClassesAndId(selector) {
  var _parseCssClassIdSelec = (0, _parseCssClassIdSelector2.default)(selector);

  var classNames = _parseCssClassIdSelec.classNames;
  var id = _parseCssClassIdSelec.id;


  var classesAndId = {};

  if (classNames.length) {
    classesAndId.class = classNames.join(' ');
  }

  if (id) {
    classesAndId.id = id;
  }

  return classesAndId;
};

/**
 * Return a creator function with properties having HTML tag names with values
 * being creator functions for the respective HTML element.
 *
 * The stand-alone returned creator function is meant to be used with custom
 * components
 *
 * @param {Function} createElement - function producing virtual nodes - typically the function used for JSX
 * @return {Function} - explained above
 */
module.exports = function (createElement) {
  /* eslint-disable complexity */
  if (typeof createElement !== 'function') {
    throw new TypeError('Expected createElement to be a function');
  }

  var creator = function creator(tagOrComponent) {
    return function (classesAndId, attrs) {
      for (var _len = arguments.length, children = Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
        children[_key - 2] = arguments[_key];
      }

      var attrsToPass = attrs || {},
          childrenToPass = children || [];

      if (Array.isArray(attrsToPass)) {
        // case: div('.hello', ['hi'])
        childrenToPass = attrsToPass;
        attrsToPass = {};
      } else if ((typeof attrsToPass === 'undefined' ? 'undefined' : _typeof(attrsToPass)) !== 'object') {
        // case: div('.hello', 7)
        childrenToPass = [attrsToPass];
        attrsToPass = {};
      }

      if (Array.isArray(classesAndId)) {
        // case: div(['hi'])
        childrenToPass = classesAndId;
      } else if ((typeof classesAndId === 'undefined' ? 'undefined' : _typeof(classesAndId)) === 'object') {
        // case: div({tabindex: 4})
        attrsToPass = classesAndId;
      }

      if (typeof classesAndId === 'string' && (classesAndId.indexOf('.') === 0 || classesAndId.indexOf('#') === 0)) {
        // case: div('.hello')
        (0, _objectAssign2.default)(attrsToPass, getClassesAndId(classesAndId));
      } else if (classesAndId !== undefined && (typeof classesAndId === 'undefined' ? 'undefined' : _typeof(classesAndId)) !== 'object') {
        // case: div(2342374)
        childrenToPass = [classesAndId];
      }

      return createElement.apply(undefined, [tagOrComponent, attrsToPass].concat(_toConsumableArray(childrenToPass)));
    };
  };

  // attach each HTML creator function to a creator function for custom components
  return _htmlTags2.default.reduce(function (acc, tag) {
    acc[tag] = creator(tag);

    return acc;
  }, creator);
};
